### Annotating

The Annotation tool  (shortcut A) adds notes and correction marks to glyph layers.
When the tool is active, the Info box (“View” → “Show Info”, Cmd-Shift-I) turns into a small palette holding a range of annotation tools.

Choose “Edit” → “Select All” (Cmd-A) to select all annotations in the currently active glyph layer.
Move selected annotations with the arrow keys.
Hold down Shift for increments of 10, and Command for increments of 100 units.
Press the Delete key to remove all selected annotations.

#### Annotation Cursor

The first tool in the Annotation palette is the Annotation Selection tool .
Use it to click-select annotations.
Shift-click to select multiple annotations at once.

#### Annotation Text

Place snippets of text with the Text Annotation tool .
Click to add a new text annotation, double-click an annotation to edit its text.
A text snippet can span across multiple lines.
The handle on the right controls the width of the text box.

#### Annotation Arrow

The Arrow Annotation tool  adds red arrows onto the canvas.
Use the handle on an arrow stem to control its rotation.

#### Annotation Circle

The Circle Annotation tool  adds red circles onto the canvas.
The handle at the bottom of the circle controls its diameter.

#### Plus & Minus Annotations

Many designers use plus and minus signs to indicate that a counter, a bowl, or a stem should be thickened or thinned.
Click the plus  or minus  button and then click on the canvas to add the symbols to the relevant area.